==> derby-0.1.2.tgz: package/lib/derby.browser.js <==
var Dom, History, Page, Route, View, modelHelper, racer;
racer = require('racer');
modelHelper = require('./modelHelper');
Dom = require('./Dom');
View = require('./View');
History = require('./History');
Route = require('express/lib/router/route');
Page = function() {};
Page.prototype = {
  render: function(ctx) {
    return this.view.render(this.model, ctx);
  },
  redirect: function(url) {
    if (url === 'back') {
      return this.history.back();
    }
    if (url === 'home') {
      url = '\\';
    }
    return this.history.replace(url, true);
  }
};
exports.createApp = function(appModule) {
  var appExports, dom, history, model, name, page, routes, template, view, _ref;
  appExports = appModule.exports;
  appExports.view = view = new View;
  routes = {};
  ['get', 'post', 'put', 'del'].forEach(function(method) {
    var queue;
    queue = routes[method] = [];
    return appExports[method] = function(pattern, callback) {
      return queue.push(new Route(method, pattern, callback));
    };
  });
  history = new History(routes, page = new Page);
  model = view.model = racer.model;
  dom = view.dom = new Dom(model, appExports, history);
  modelHelper.init(model, dom, view);
  appExports.ready = function(fn) {
    return racer.onready = function() {
      return fn(model);
    };
  };
  page.view = view;
  page.model = model;
  _ref = "$$templates$$";
  for (name in _ref) {
    template = _ref[name];
    view.make(name, template);
  }
  appModule.exports = function(modelBundle, ctx) {
    model.on('initialized', function() {
      return view.render(model, ctx, true);
    });
    racer.init(modelBundle);
    dom.init();
    return appExports;
  };
  return appExports;
};

==> derby-0.1.3.tgz: package/lib/derby.browser.js <==
var Dom, History, Page, Route, View, modelHelper, racer;

racer = require('racer');

modelHelper = require('./modelHelper');

Dom = require('./Dom');

View = require('./View');

History = require('./History');

Route = require('express/lib/router/route');

Page = function() {};

Page.prototype = {
  render: function(ctx) {
    return this.view.render(this.model, ctx);
  },
  redirect: function(url) {
    if (url === 'back') return this.history.back();
    if (url === 'home') url = '\\';
    return this.history.replace(url, true);
  }
};

exports.createApp = function(appModule) {
  var appExports, dom, history, model, name, page, routes, template, view, _ref;
  appExports = appModule.exports;
  appExports.view = view = new View;
  routes = {};
  ['get', 'post', 'put', 'del'].forEach(function(method) {
    var queue;
    queue = routes[method] = [];
    return appExports[method] = function(pattern, callback) {
      return queue.push(new Route(method, pattern, callback));
    };
  });
  history = new History(routes, page = new Page);
  model = view.model = racer.model;
  dom = view.dom = new Dom(model, appExports, history);
  modelHelper.init(model, dom, view);
  appExports.ready = function(fn) {
    return racer.onready = function() {
      return fn(model);
    };
  };
  page.view = view;
  page.model = model;
  _ref = "$$templates$$";
  for (name in _ref) {
    template = _ref[name];
    view.make(name, template);
  }
  appModule.exports = function(modelBundle, ctx) {
    model.on('initialized', function() {
      return view.render(model, ctx, true);
    });
    racer.init(modelBundle);
    dom.init();
    return appExports;
  };
  return appExports;
};
